@@ -1,4 +1,4 @@
-/* $Id: asapinstance.c 2777 2013-05-30 11:33:33Z dreibh $
+/* $Id$
  * --------------------------------------------------------------------------
  *
  *              //===//   //=====   //===//   //       //   //===//
@@ -9,7 +9,7 @@
  *
  * ------------- An Efficient RSerPool Prototype Implementation -------------
  *
- * Copyright (C) 2002-2013 by Thomas Dreibholz
+ * Copyright (C) 2002-2015 by Thomas Dreibholz
  *
  * Acknowledgements:
  * Realized in co-operation between Siemens AG and
@@ -301,7 +301,7 @@ static void asapInstanceConfigure(struct ASAPInstance* asapInstance,
 static bool asapInstanceConnectToRegistrar(struct ASAPInstance* asapInstance,
                                            int                  sd)
 {
-   RegistrarIdentifierType registrarIdentifier;
+   RegistrarIdentifierType registrarIdentifier = 0;
 #ifdef HAVE_SCTP_DELAYED_SACK
    struct sctp_sack_info   sctpSACKInfo;
 #endif
