@@ -1,4 +1,4 @@
-/* $Id: attacker.cc 2777 2013-05-30 11:33:33Z dreibh $
+/* $Id$
  * --------------------------------------------------------------------------
  *
  *              //===//   //=====   //===//   //       //   //===//
@@ -9,7 +9,7 @@
  *
  * ------------- An Efficient RSerPool Prototype Implementation -------------
  *
- * Copyright (C) 2002-2013 by Thomas Dreibholz
+ * Copyright (C) 2002-2015 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -119,11 +119,7 @@ int main(int argc, char** argv)
          }
          else if(sscanf((const char*)&argv[i][8], "LeastUsedDegradation:%lf", &degradation) == 1) {
             loadInfo.rli_load_degradation = (unsigned int)rint(degradation * (double)PPV_MAX_LOAD_DEGRADATION);
-            if(loadInfo.rli_load_degradation < 0) {
-               fputs("ERROR: Bad LUD degradation value!\n", stderr);
-               exit(1);
-            }
-            else if(loadInfo.rli_load_degradation > PPV_MAX_LOAD_DEGRADATION) {
+            if(loadInfo.rli_load_degradation > PPV_MAX_LOAD_DEGRADATION) {
                fputs("ERROR: Bad LUD degradation value!\n", stderr);
                exit(1);
             }
@@ -131,11 +127,7 @@ int main(int argc, char** argv)
          }
          else if(sscanf((const char*)&argv[i][8], "PriorityLeastUsed:%lf", &degradation) == 1) {
             loadInfo.rli_load_degradation = (unsigned int)rint(degradation * (double)PPV_MAX_LOAD_DEGRADATION);
-            if(loadInfo.rli_load_degradation < 0) {
-               fputs("ERROR: Bad PLU degradation value!\n", stderr);
-               exit(1);
-            }
-            else if(loadInfo.rli_load_degradation > PPV_MAX_LOAD_DEGRADATION) {
+            if(loadInfo.rli_load_degradation > PPV_MAX_LOAD_DEGRADATION) {
                fputs("ERROR: Bad PLU degradation value!\n", stderr);
                exit(1);
             }
@@ -159,11 +151,7 @@ int main(int argc, char** argv)
             }
             loadInfo.rli_load_dpf         = (unsigned int)rint(dpf * (double)PPV_MAX_LOADDPF);
             loadInfo.rli_load_degradation = (unsigned int)rint(degradation * (double)PPV_MAX_LOAD_DEGRADATION);
-            if(loadInfo.rli_load_degradation < 0) {
-               fputs("ERROR: Bad LU-DPF degradation value!\n", stderr);
-               exit(1);
-            }
-            else if(loadInfo.rli_load_degradation > PPV_MAX_LOAD_DEGRADATION) {
+            if(loadInfo.rli_load_degradation > PPV_MAX_LOAD_DEGRADATION) {
                fputs("ERROR: Bad LU-DPF degradation value!\n", stderr);
                exit(1);
             }
