@@ -1,4 +1,4 @@
-/* $Id: fractalpooluser.cc 2777 2013-05-30 11:33:33Z dreibh $
+/* $Id$
  * --------------------------------------------------------------------------
  *
  *              //===//   //=====   //===//   //       //   //===//
@@ -9,7 +9,7 @@
  *
  * ------------- An Efficient RSerPool Prototype Implementation -------------
  *
- * Copyright (C) 2002-2013 by Thomas Dreibholz
+ * Copyright (C) 2002-2015 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -288,7 +288,7 @@ void FractalPU::startNextJob()
 
    size_t remaining = CurrentThreads;
    for(size_t yPosition = 0;yPosition < yCount;yPosition++) {
-      const size_t xCount = (yPosition < yCount - 1) ? min(remaining, yCount) : remaining;
+      const size_t xCount = (yPosition < yCount - 1) ? std::min(remaining, yCount) : remaining;
       if(xCount > 0) {
          const size_t xStep = (size_t)rint(Parameter.Width / xCount);
          remaining -= xCount;
@@ -508,7 +508,7 @@ void FractalPU::about()
    QMessageBox::about(this, tr("About Fractal Pool User"),
       "<center>"
          "<b>Fractal Pool User</b><br>"
-         "Copyright (C) 2002-2013 by Thomas Dreibholz"
+         "Copyright (C) 2002-2015 by Thomas Dreibholz"
       "</center>");
 }
 
@@ -657,7 +657,7 @@ void FractalCalculationThread::run()
 
                   // ====== Handle received result chunks ===================
                   rsp_sndrcvinfo rinfo;
-                  char           buffer[max(sizeof(FGPData), sizeof(rsp_sndrcvinfo))];
+                  char           buffer[std::max(sizeof(FGPData), sizeof(rsp_sndrcvinfo))];
                   int            flags   = 0;
                   size_t         packets = 0;
                   ssize_t        received;
@@ -956,7 +956,7 @@ int main(int argc, char** argv)
                     "2.0kde",
                     ki18n("A KDE/RSerPool Fractal Generator Pool User"),
                     KAboutData::License_GPL_V3,
-                    ki18n("Copyright (C) 2009-2013 Thomas Dreibholz"));
+                    ki18n("Copyright (C) 2009-2015 Thomas Dreibholz"));
    KCmdLineArgs::init(argc, argv, &about);
    KApplication application;
 #else
