@@ -1,4 +1,4 @@
-/* $Id: fractalpooluser.h 2777 2013-05-30 11:33:33Z dreibh $
+/* $Id$
  * --------------------------------------------------------------------------
  *
  *              //===//   //=====   //===//   //       //   //===//
@@ -9,7 +9,7 @@
  *
  * ------------- An Efficient RSerPool Prototype Implementation -------------
  *
- * Copyright (C) 2002-2013 by Thomas Dreibholz
+ * Copyright (C) 2002-2015 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -78,8 +78,8 @@ class ImageDisplay : public QWidget
                         const size_t width, const size_t height,
                         const unsigned int color) {
       if(Image) {
-         for(size_t j = y;j < min(y + height, (size_t)Image->height());j++) {
-            for(size_t i = x;i < min(x + width, (size_t)Image->width());i++) {
+         for(size_t j = y;j < std::min(y + height, (size_t)Image->height());j++) {
+            for(size_t i = x;i < std::min(x + width, (size_t)Image->width());i++) {
                Image->setPixel(i, j, color);
             }
          }
