@@ -1,4 +1,4 @@
-/* $Id: loglevel.c 2777 2013-05-30 11:33:33Z dreibh $
+/* $Id$
  * --------------------------------------------------------------------------
  *
  *              //===//   //=====   //===//   //       //   //===//
@@ -9,7 +9,7 @@
  *
  * ------------- An Efficient RSerPool Prototype Implementation -------------
  *
- * Copyright (C) 2002-2013 by Thomas Dreibholz
+ * Copyright (C) 2002-2015 by Thomas Dreibholz
  *
  * Acknowledgements:
  * Realized in co-operation between Siemens AG and
@@ -74,18 +74,18 @@ void setLogColor(const unsigned int color)
 /* ###### Initialize logfile ############################################# */
 static bool initLogFile(const unsigned int logLevel, const char* fileName, const char* fileMode)
 {
+   FILE* newLogFile;
+
    finishLogging();
    if(fileName != NULL) {
-      *gStdLog = fopen(fileName,fileMode);
-      if(*gStdLog != NULL) {
+      newLogFile = fopen(fileName,fileMode);
+      if(newLogFile != NULL) {
+         *gStdLog     = newLogFile;
          gCloseStdLog = true;
-         gLogLevel   = min(logLevel,MAX_LOGLEVEL);
+         gLogLevel    = min(logLevel,MAX_LOGLEVEL);
          return(true);
       }
    }
-
-   *gStdLog     = stderr;
-   gCloseStdLog = false;
    return(false);
 }
 
