@@ -1,4 +1,4 @@
-/* $Id: rspserver.cc 2777 2013-05-30 11:33:33Z dreibh $
+/* $Id$
  * --------------------------------------------------------------------------
  *
  *              //===//   //=====   //===//   //       //   //===//
@@ -9,7 +9,7 @@
  *
  * ------------- An Efficient RSerPool Prototype Implementation -------------
  *
- * Copyright (C) 2002-2013 by Thomas Dreibholz
+ * Copyright (C) 2002-2015 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,6 +27,8 @@
  * Contact: dreibh@iem.uni-due.de
  */
 
+#include <string>
+
 #include "rserpool.h"
 #include "breakdetector.h"
 #include "tagitem.h"
@@ -168,11 +170,7 @@ start:
          }
          else if(sscanf((const char*)&argv[i][8], "LeastUsedDegradation:%lf", &degradation) == 1) {
             loadInfo.rli_load_degradation = (unsigned int)rint(degradation * (double)PPV_MAX_LOAD_DEGRADATION);
-            if(loadInfo.rli_load_degradation < 0) {
-               fputs("ERROR: Bad LUD degradation value!\n", stderr);
-               exit(1);
-            }
-            else if(loadInfo.rli_load_degradation > PPV_MAX_LOAD_DEGRADATION) {
+            if(loadInfo.rli_load_degradation > PPV_MAX_LOAD_DEGRADATION) {
                fputs("ERROR: Bad LUD degradation value!\n", stderr);
                exit(1);
             }
@@ -180,11 +178,7 @@ start:
          }
          else if(sscanf((const char*)&argv[i][8], "PriorityLeastUsed:%lf", &degradation) == 1) {
             loadInfo.rli_load_degradation = (unsigned int)rint(degradation * (double)PPV_MAX_LOAD_DEGRADATION);
-            if(loadInfo.rli_load_degradation < 0) {
-               fputs("ERROR: Bad PLU degradation value!\n", stderr);
-               exit(1);
-            }
-            else if(loadInfo.rli_load_degradation > PPV_MAX_LOAD_DEGRADATION) {
+            if(loadInfo.rli_load_degradation > PPV_MAX_LOAD_DEGRADATION) {
                fputs("ERROR: Bad PLU degradation value!\n", stderr);
                exit(1);
             }
@@ -208,11 +202,7 @@ start:
             }
             loadInfo.rli_load_dpf         = (unsigned int)rint(dpf * (double)PPV_MAX_LOADDPF);
             loadInfo.rli_load_degradation = (unsigned int)rint(degradation * (double)PPV_MAX_LOAD_DEGRADATION);
-            if(loadInfo.rli_load_degradation < 0) {
-               fputs("ERROR: Bad LU-DPF degradation value!\n", stderr);
-               exit(1);
-            }
-            else if(loadInfo.rli_load_degradation > PPV_MAX_LOAD_DEGRADATION) {
+            if(loadInfo.rli_load_degradation > PPV_MAX_LOAD_DEGRADATION) {
                fputs("ERROR: Bad LU-DPF degradation value!\n", stderr);
                exit(1);
             }
@@ -360,6 +350,10 @@ start:
          if(!(strncmp(argv[i], "-chargenmaxthreads=", 19))) {
             maxThreads = atol((const char*)&argv[i][19]);
          }
+         else if(!(strncmp(argv[i], "-chargen", 8))) {
+            fprintf(stderr, "ERROR: Unknown Character Generator parameter: %s!\n", argv[i]);
+            exit(1);
+         }
       }
 
       TCPLikeServer::poolElement("Character Generator Server - Version 1.0",
@@ -436,6 +430,10 @@ start:
          else if(!(strncmp(argv[i], "-fgpfailureafter=", 17))) {
             settings.FailureAfter = atol((const char*)&argv[i][17]);
          }
+         else if(!(strncmp(argv[i], "-fgp", 4))) {
+            fprintf(stderr, "ERROR: Unknown Fractal Generator parameter: %s!\n", argv[i]);
+            exit(1);
+         }
       }
 
       TCPLikeServer::poolElement("Fractal Generator Server - Version 1.0",
@@ -518,6 +516,10 @@ start:
                cleanShutdownProbability = 1.0;
             }
          }
+         else if(!(strncmp(argv[i], "-cap", 4))) {
+            fprintf(stderr, "ERROR: Unknown CalcApp parameter: %s!\n", argv[i]);
+            exit(1);
+         }
       }
 
       CalcAppServer calcAppServer(maxJobs, objectName, vectorFileName, scalarFileName,
@@ -581,6 +583,16 @@ start:
          else if(!(strncmp(argv[i], "-sscachedirectory=", 18))) {
             settings.CacheDirectory = (const char*)&argv[i][18];
          }
+         else if(!(strncmp(argv[i], "-sskeyring=", 11))) {
+            settings.Keyring = (const char*)&argv[i][11];
+         }
+         else if(!(strncmp(argv[i], "-sstrustdb=", 11))) {
+            settings.TrustDB = (const char*)&argv[i][11];
+         }
+         else if(!(strncmp(argv[i], "-ss", 3))) {
+            fprintf(stderr, "ERROR: Unknown Scripting Service parameter: %s!\n", argv[i]);
+            exit(1);
+         }
       }
       if(!policyChanged) {
          loadInfo.rli_load_degradation = (unsigned int)rint((1.0 / maxThreads) * (double)PPV_MAX_LOAD_DEGRADATION);
