@@ -1,4 +1,4 @@
-/* $Id: scriptingservice.cc 2777 2013-05-30 11:33:33Z dreibh $
+/* $Id: scriptingservice.cc 2868 2015-06-12 09:15:14Z dreibh $
  * --------------------------------------------------------------------------
  *
  *              //===//   //=====   //===//   //       //   //===//
@@ -9,7 +9,7 @@
  *
  * ------------- An Efficient RSerPool Prototype Implementation -------------
  *
- * Copyright (C) 2002-2013 by Thomas Dreibholz
+ * Copyright (C) 2002-2015 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,6 +32,7 @@
 #include "timeutilities.h"
 #include "stringutilities.h"
 #include "loglevel.h"
+#include "memfile.h"
 
 #include <unistd.h>
 #include <stdlib.h>
@@ -141,6 +142,8 @@ void ScriptingServer::scriptingPrintParameters(const void* userData)
    printf("   Cache Max Size          = %llu [KiB]\n", settings->CacheMaxSize / 1024);
    printf("   Cache Max Entries       = %u\n", settings->CacheMaxEntries);
    printf("   Cache Directory         = %s\n", settings->CacheDirectory.c_str());
+   printf("   Keyring                 = %s\n", settings->Keyring.c_str());
+   printf("   Trust DB                = %s\n", settings->TrustDB.c_str());
 }
 
 
@@ -153,7 +156,7 @@ void ScriptingServer::rejectNewSession(int sd)
    if(uname(&systemInfo) != 0) {
       systemInfo.nodename[0] = 0x00;
    }
-   
+
    NotReady* notReady = (NotReady*)&buffer;
    memset((char*)&notReady->Info, 0x00, sizeof(notReady->Info));
    snprintf((char*)&notReady->Info, sizeof(notReady->Info), "%s", systemInfo.nodename);
@@ -321,13 +324,12 @@ EventHandlingResult ScriptingServer::handleUploadMessage(const Upload* upload)
       ProcessingStarted = getMicroTime();
 
       printTimeStamp(stdlog);
-      fprintf(stdlog, "S%04d: Upload completed (%s: %1.0lf KiB in %1.1lf s; %1.1lf KiB/s) => starting work in directory \"%s\" ...\n",
+      fprintf(stdlog, "S%04d: Upload completed (%s: %1.0lf KiB in %1.1lf s; %1.1lf KiB/s)\n",
               RSerPoolSocketDescriptor,
               (WaitingForEnvironment == true) ? EnvironmentName : InputName,
               ceil((double)UploadSize / 1024.0),
               (ProcessingStarted - UploadStarted) / 1000000.0,
-              (double)((double)UploadSize / 1024.0) / ((ProcessingStarted - UploadStarted) / 1000000.0),
-              Directory);
+              (double)((double)UploadSize / 1024.0) / ((ProcessingStarted - UploadStarted) / 1000000.0));
 
 
       // ====== Continue upload with environment file =======================
@@ -348,9 +350,12 @@ EventHandlingResult ScriptingServer::handleUploadMessage(const Upload* upload)
                fprintf(stdlog, "%02x", (unsigned int)EnvironmentHash[i]);
             }
             fputs("\n", stdlog);
-            Cache.storeInCache((const uint8_t*)&EnvironmentHash,
-                               EnvironmentName,
-                               UploadSize);
+            if(!checkEnvironment(EnvironmentName)) {
+               fprintf(stdlog, "S%04d: Invalid environment in directory \"%s\"\n",
+                       RSerPoolSocketDescriptor, Directory);
+               return(EHR_Abort);
+            }
+            Cache.storeInCache((const uint8_t*)&EnvironmentHash, EnvironmentName, UploadSize);
          }
 
          // ====== Start to do actual work ==================================
@@ -436,40 +441,44 @@ EventHandlingResult ScriptingServer::sendStatus(const int exitStatus)
 // ###### Perform work package download #####################################
 EventHandlingResult ScriptingServer::performDownload()
 {
-   Download download;
-   size_t   dataLength;
-   ssize_t  sent;
-
-   FILE* fh = fopen(OutputName, "r");
-   if(fh != NULL) {
+   struct MemFile* memFile = openMemFile(OutputName);
+   if(memFile != NULL) {
       DownloadStarted = getMicroTime();
       printTimeStamp(stdlog);
       fprintf(stdlog, "S%04d: Processing completed (%1.1lf s) => starting download of results in directory \"%s\" ...\n",
               RSerPoolSocketDescriptor,
               (DownloadStarted - ProcessingStarted) / 1000000.0,
               Directory);
+
+      size_t totalBytesSent = 0;
       for(;;) {
-         dataLength = fread((char*)&download.Data, 1, sizeof(download.Data), fh);
-         if(dataLength >= 0) {
-            download.Header.Type   = SPT_DOWNLOAD;
-            download.Header.Flags  = 0x00;
-            download.Header.Length = htons(dataLength + sizeof(struct ScriptingCommonHeader));
-            if(Settings.VerboseMode) {
-               fputs(".", stdlog);
-               fflush(stdlog);
-            }
-            sent = rsp_sendmsg(RSerPoolSocketDescriptor,
-                               (const char*)&download, dataLength + sizeof(struct ScriptingCommonHeader), 0,
-                               0, htonl(PPID_SP), 0, 0, 0, Settings.TransmitTimeout);
-            if(sent != (ssize_t)(dataLength + sizeof(struct ScriptingCommonHeader))) {
-               fclose(fh);
-               printTimeStamp(stdlog);
-               fprintf(stdlog, "S%04d: Download data transmission error: %s\n",
-                       RSerPoolSocketDescriptor, strerror(errno));
-               return(EHR_Abort);
-            }
-            DownloadSize += (unsigned long long)dataLength;
+         Download download;
+         size_t   dataLength = memFile->Length - totalBytesSent;
+         if(dataLength > sizeof(download.Data)) {
+            dataLength = sizeof(download.Data);
          }
+
+         // NOTE: end-of-file will be indicated by empty SPT_DOWNLOAD message!
+         download.Header.Type   = SPT_DOWNLOAD;
+         download.Header.Flags  = 0x00;
+         download.Header.Length = htons(dataLength + sizeof(struct ScriptingCommonHeader));
+         memcpy((void*)&download.Data, &memFile->Address[totalBytesSent], dataLength);
+         if(Settings.VerboseMode) {
+            fputs(".", stdlog);
+            fflush(stdlog);
+         }
+         const ssize_t sent = rsp_sendmsg(RSerPoolSocketDescriptor,
+                                 (const char*)&download, dataLength + sizeof(struct ScriptingCommonHeader), 0,
+                                 0, htonl(PPID_SP), 0, 0, 0, Settings.TransmitTimeout);
+         if(sent != (ssize_t)(dataLength + sizeof(struct ScriptingCommonHeader))) {
+            closeMemFile(memFile);
+            printTimeStamp(stdlog);
+            fprintf(stdlog, "S%04d: Download data transmission error: %s\n",
+                     RSerPoolSocketDescriptor, strerror(errno));
+            return(EHR_Abort);
+         }
+         DownloadSize += (unsigned long long)dataLength;
+
          if(dataLength <= 0) {
             const unsigned long long downloadFinished = getMicroTime();
             printTimeStamp(stdlog);
@@ -481,11 +490,13 @@ EventHandlingResult ScriptingServer::performDownload()
                   Directory);
             break;
          }
+
+         totalBytesSent += dataLength;
       }
       if(Settings.VerboseMode) {
          fputs("\n", stdlog);
       }
-      fclose(fh);
+      closeMemFile(memFile);
    } else {
       printTimeStamp(stdlog);
       fprintf(stdlog, "S%04d: There are no results in directory \"%s\"!\n",
@@ -497,6 +508,25 @@ EventHandlingResult ScriptingServer::performDownload()
 }
 
 
+// ###### Check new environment #############################################
+bool ScriptingServer::checkEnvironment(const char* environmentName)
+{
+   char sscmd[1024];
+   char callcmd[1024];
+
+   snprintf((char*)&sscmd, sizeof(sscmd), "scriptingcontrol check-environment \"%s\" \"%s\" \"%s\" \"%s\"",
+            Directory, environmentName, Settings.Keyring.c_str(), Settings.TrustDB.c_str());
+   snprintf((char*)&callcmd, sizeof(callcmd), "if [ -e ./scriptingcontrol ] ; then ./%s ; else %s ; fi", sscmd, sscmd);
+
+   int status = system((char*)&callcmd);
+   if(status < 0) {
+      perror("Failed to run scriptingcontrol for checking the environment");
+      return(false);
+   }
+
+   return( (WIFEXITED(status)) && (WEXITSTATUS(status) == 0) );
+}
+
 // ###### Start working script ##############################################
 EventHandlingResult ScriptingServer::startWorking()
 {
@@ -513,16 +543,17 @@ EventHandlingResult ScriptingServer::startWorking()
       dup2(stdlogFD, STDERR_FILENO);
 
       // ====== Run script ==================================================
-      execlp("./scriptingcontrol",
+      struct stat buffer;
+      const char* scriptingControl = "./scriptingcontrol";
+      if(stat(scriptingControl, &buffer) != 0) {
+         scriptingControl = "scriptingcontrol";   // Try standard location!
+      }
+      execlp(scriptingControl,
              "scriptingcontrol",
              "run", Directory, INPUT_NAME, OUTPUT_NAME, STATUS_NAME,
-             (GotEnvironment == true) ? ENVIRONMENT_NAME : NULL,
-             (char*)NULL);
-      // Try standard location ...
-      execlp("scriptingcontrol",
-             "scriptingcontrol",
-             "run", Directory, INPUT_NAME, OUTPUT_NAME, STATUS_NAME,
-             (GotEnvironment == true) ? ENVIRONMENT_NAME : NULL,
+             ((GotEnvironment == true) ? ENVIRONMENT_NAME : ""),
+             Settings.Keyring.c_str(),
+             Settings.TrustDB.c_str(),
              (char*)NULL);
       perror("Failed to start scriptingcontrol");
       exit(1);
