@@ -1,4 +1,4 @@
-/* $Id: scriptingservice.h 2777 2013-05-30 11:33:33Z dreibh $
+/* $Id$
  * --------------------------------------------------------------------------
  *
  *              //===//   //=====   //===//   //       //   //===//
@@ -9,7 +9,7 @@
  *
  * ------------- An Efficient RSerPool Prototype Implementation -------------
  *
- * Copyright (C) 2002-2013 by Thomas Dreibholz
+ * Copyright (C) 2002-2015 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -50,6 +50,8 @@ class ScriptingServer : public TCPLikeServer
       unsigned int       CacheMaxEntries;
       unsigned long long CacheMaxSize;
       std::string        CacheDirectory;
+      std::string        Keyring;
+      std::string        TrustDB;
       bool               KeepTempDirs;
       bool               VerboseMode;
    };
@@ -75,6 +77,7 @@ class ScriptingServer : public TCPLikeServer
    virtual EventHandlingResult initializeSession();
    virtual void finishSession(EventHandlingResult result);
    virtual EventHandlingResult syncTimerEvent(const unsigned long long now);
+   bool checkEnvironment(const char* environmentName);
    EventHandlingResult startWorking();
    bool hasFinishedWork(int& exitStatus);
    EventHandlingResult sendStatus(const int exitStatus);
