@@ -1,4 +1,4 @@
-/* $Id: udplikeserver.cc 2777 2013-05-30 11:33:33Z dreibh $
+/* $Id$
  * --------------------------------------------------------------------------
  *
  *              //===//   //=====   //===//   //       //   //===//
@@ -9,7 +9,7 @@
  *
  * ------------- An Efficient RSerPool Prototype Implementation -------------
  *
- * Copyright (C) 2002-2013 by Thomas Dreibholz
+ * Copyright (C) 2002-2015 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,6 +27,8 @@
  * Contact: dreibh@iem.uni-due.de
  */
 
+#include <string>
+
 #include "udplikeserver.h"
 #include "timeutilities.h"
 #include "netutilities.h"
@@ -272,7 +274,7 @@ void UDPLikeServer::poolElement(const char*          programTitle,
                            timeout = 0;
                         }
                         else {
-                           timeout = min(timeout, NextTimerTimeStamp - now);
+                           timeout = std::min(timeout, NextTimerTimeStamp - now);
                         }
                      }
 
